@@ -257,16 +257,18 @@ Player::showOptions (Hand *player, int upCard, int numHands)
   double value, bestValue;
   gchar *markup = NULL;
   gchar *tmpstr = NULL;
-  gchar *mark_list[6];
+  gchar *mark_list[7];
 
   reset ();
 
   num_options = 0;
 
+  mark_list[num_options++] = g_strdup_printf ("%s\n", _("Player expected values"));
+
   // Player can always stand.
 
   bestValue = value = getValueStand (*player, upCard);
-  mark_list[num_options++] = g_strdup_printf ("%s     %9.4lf\n", 
+  mark_list[num_options++] = g_strdup_printf ("  %s     %8.2lf%%\n", 
                                               _("Stand"), value * 100);
   bestOption = KEY_S;
 
@@ -275,7 +277,7 @@ Player::showOptions (Hand *player, int upCard, int numHands)
     {
       value = getValueHit (*player, upCard);
       
-      mark_list[num_options++] = g_strdup_printf ("%s       %9.4lf\n", 
+      mark_list[num_options++] = g_strdup_printf ("  %s       %8.2lf%%\n", 
                                                   _("Hit"), value * 100);
       if (value > bestValue)
         {
@@ -287,7 +289,7 @@ Player::showOptions (Hand *player, int upCard, int numHands)
       if (bj_hand_can_be_doubled ())
         {
           value = getValueDoubleDown (*player, upCard);
-          mark_list[num_options++] = g_strdup_printf ("%s    %9.4lf\n", 
+          mark_list[num_options++] = g_strdup_printf ("  %s    %8.2lf%%\n", 
                                                       _("Double"), value * 100);
           if (value > bestValue)
             {
@@ -302,7 +304,7 @@ Player::showOptions (Hand *player, int upCard, int numHands)
   if (bj_hand_can_be_split ())
     {
       value = getValueSplit(player->cards[0].value (), upCard);
-      mark_list[num_options++] = g_strdup_printf ("%s     %9.4lf\n", 
+      mark_list[num_options++] = g_strdup_printf ("  %s     %8.2lf%%\n", 
                                                   _("Split"), value * 100);
       if (value > bestValue)
         {
@@ -315,7 +317,7 @@ Player::showOptions (Hand *player, int upCard, int numHands)
   if (bj_hand_can_be_surrendered ())
     {
       value = -0.5;
-      mark_list[num_options++] = g_strdup_printf ("%s %9.4lf\n", 
+      mark_list[num_options++] = g_strdup_printf ("  %s %8.2lf%%\n", 
                                                   _("Surrender"), value * 100);
       if (value > bestValue)
         {
@@ -343,6 +345,10 @@ Player::showOptions (Hand *player, int upCard, int numHands)
       tmpstr = g_strconcat (mark_list[0], mark_list[1], mark_list[2], 
                             mark_list[3], mark_list[4], NULL);
       break;
+    case 6:
+      tmpstr = g_strconcat (mark_list[0], mark_list[1], mark_list[2], 
+                            mark_list[3], mark_list[4], mark_list[5], NULL);
+      break;
     default:
       break;
     }
@@ -355,7 +361,7 @@ Player::showOptions (Hand *player, int upCard, int numHands)
       g_free (tmpstr);
       for (int i = 0; i < num_options; i++)
         g_free (mark_list[i]);
-      bj_draw_playing_area_text (markup, 25, 125);
+      bj_draw_playing_area_text (markup, 10, 120);
       g_free (markup);
     }
   return bestOption;
@@ -435,7 +441,7 @@ Probabilities::showProbabilities (BJShoe *distribution, int upCard,
                                   bool condition)
 {
   gchar *markup;
-  gchar *mark_list[6];
+  gchar *mark_list[7];
   
   computeProbabilities (*distribution);
   double notBlackjack;
@@ -445,24 +451,24 @@ Probabilities::showProbabilities (BJShoe *distribution, int upCard,
     notBlackjack = 1;
   reset();
 
-  mark_list[0] = g_strdup_printf ("%s         %.4lf\n", _("Bust"),
-                                  getProbabilityBust (upCard) / notBlackjack);
+  mark_list[0] = g_strdup_printf ("%s\n", _("Dealer hand probabilities"));
+  mark_list[1] = g_strdup_printf ("  %s         %5.2lf%%\n", _("Bust"),
+                                  getProbabilityBust (upCard) * 100.0 / notBlackjack);
   for (int count = 17; count <= 21; count++)
     {
-      mark_list[count-16] = g_strdup_printf ("%2d           %.4lf\n", count,
+      mark_list[count-15] = g_strdup_printf ("  %2d           %5.2lf%%\n", count,
                                              getProbabilityCount (count, upCard)
-                                             / notBlackjack);
+                                             * 100.0 / notBlackjack);
     }
-  mark_list[5] = g_strdup_printf ("%s    %.4lf\n", _("Blackjack"),
-                                  condition ? 0.0 : getProbabilityBlackjack (upCard));
+
   markup = g_strconcat ("<span size=\"10000\" font_family=\"fixed\" foreground=\"white\">", 
                         mark_list[0], mark_list[1], mark_list[2], mark_list[3], 
-                        mark_list[4], mark_list[5], 
+                        mark_list[4], mark_list[5], mark_list[6],
                         "</span>", NULL);
   
-  for (int i = 0; i < 6; i++)
+  for (int i = 0; i < 7; i++)
     g_free (mark_list[i]);
-  bj_draw_playing_area_text (markup, 25, 25);
+  bj_draw_playing_area_text (markup, 10, 10);
   g_free (markup);
 }
 
